#
# spec file for package libstrophe
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define c_lib   libstrophe0
Name:           libstrophe
Version:        0.9.3
Release:        lp152.1.1
Summary:        A XMPP library for C
License:        GPL-3.0-or-later OR MIT
Group:          Development/Libraries/C and C++
Url:            http://strophe.im/libstrophe/
Source0:        https://github.com/strophe/%{name}/archive/%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  libopenssl-devel
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  make
BuildRequires:  pkgconfig

%description
Strophe is a collection of libraries for speaking the XMPP protocol.

While most XMPP libraries and implementations are focused on chat-based applications,
Strophe takes a grander view.

It has been used to implement real-time games, notification systems, search engines,
as well as traditional instant messaging.

The implementations are production ready, well documented,
easy to use, and easy to extend.

%package -n libstrophe-devel
Summary:        Development files for libstrophe
Group:          Development/Libraries/C and C++ 
Requires:       libstrophe0 = %{version}

%description -n libstrophe-devel
Development files and headers for libstrophe

%package -n %{c_lib}
Summary:        A XMPP library for C
Group:          System/Libraries

%description -n %{c_lib}
The libstrophe library is a XMPP library written in C.

%prep
%setup -q

%build
mkdir m4
./bootstrap.sh
%configure --disable-static --with-libxml2
make %{?_smp_mflags}

%install
%make_install
rm %{buildroot}%{_libdir}/libstrophe.la

%post -n libstrophe0 -p /sbin/ldconfig
%postun -n libstrophe0 -p /sbin/ldconfig

%files -n libstrophe0
%license COPYING
%doc ChangeLog README
%{_libdir}/libstrophe.so.*

%files -n libstrophe-devel
%{_libdir}/libstrophe.so
%{_includedir}/strophe.h
%{_libdir}/pkgconfig/libstrophe.pc

%changelog
* Fri Oct 11 2019 Michael Vetter <mvetter@suse.com>
- Update 0.9.3:
  * PLAIN mechanism is used only when no other mechanisms are supported
  * Legacy authentication is disabled by default, can be enabled with connection flag XMPP_CONN_FLAG_LEGACY_AUTH
  * Session is not established if it is optional
  * Fixed a bug causing a reused connection not to cleanup properly
  * Improved debug logging in OpenSSL module
  * Few memory leaks fixed
* Sat Feb 24 2018 mvetter@suse.com
- Update to 0.9.2:
  * OpenSSL tls module verifies certificate by default. Set flag XMPP_CONN_FLAG_TRUST_TLS to ignore result of the verification
  * Certificate hostname verification is forced for openssl-1.0.2 and newer
  * OpenSSL tls module disables insecure SSLv2 SSLv3 and TLSv1
  * Support of handlers with the same callback function, but different userdata
  * System handlers are deleted on xmpp_conn_t reconnection. Old system handlers could cause problems
  * Default timeout for xmpp_run() is increased from 1 millisecond to 1 second in order to reduce CPU consumption
  * Reduced memory usage in expat module
  * New functions: xmpp_ctx_set_timeout(), xmpp_sha1_digest()
* Fri Sep 16 2016 mvetter@suse.com
- Update to 0.9.1:
  * Fixed bug #95 (DNS lookup failing on Cygwin)
  * Removed dependency on the check package
* Thu Sep 15 2016 mvetter@suse.com
- Update to 0.9.0:
  * IPv6 support
  * Legacy SSL support
  * Initial Android support
  * Resolver returns all SRV records instead of one. Lookup is performed
    according to RFC2052
  * xmpp_connect_raw() provides access to a xmpp_conn object just after
    establishing TCP connection. This allows to implement in-band
    registration, authentication mechanisms or serverless messaging
  * xmpp_conn_t object is reusable now and can be reconnected with saving
    all handlers, flags, jid and password
    New API:
  * xmpp_uuid_gen()
  * xmpp_connect_raw()
  * xmpp_conn_open_stream_default()
  * xmpp_conn_open_stream()
  * xmpp_conn_tls_start()
  * xmpp_conn_get_flags()
  * xmpp_conn_set_flags()
  * xmpp_conn_set_keepalive()
  * xmpp_conn_is_secured()
  * xmpp_stanza_del_attribute()
  * xmpp_stanza_get_to()
  * xmpp_stanza_get_from()
  * xmpp_stanza_set_to()
  * xmpp_stanza_set_from()
  * xmpp_stanza_reply()
  * xmpp_message_new()
  * xmpp_message_get_body()
  * xmpp_message_set_body()
  * xmpp_iq_new()
  * xmpp_presence_new()
    Exposed private API:
  * xmpp_jid_new()
  * xmpp_jid_bare()
  * xmpp_jid_node()
  * xmpp_jid_domain()
  * xmpp_jid_resource()
  * xmpp_stanza_get_attribute_count()
  * xmpp_stanza_get_attributes()
* Wed May 18 2016 mvetter@suse.com
- Update to 0.8.8:
  * XML namespace support
  * XEP-0114 support
  * Bugfixes
* Fri Jun 19 2015 cfarrell@suse.com
- license update: GPL-3.0+ or MIT
  Package is dual licensed
* Tue Jun 16 2015 g.bluehut@gmail.com
- Use variable instead of name for library package
* Wed May 27 2015 g.bluehut@gmail.com
- Define URL to source instead of only relying on local one
* Wed May 27 2015 g.bluehut@gmail.com
- Let rpm handle the detection of libxml2, remove requires libxml2
* Wed May 27 2015 g.bluehut@gmail.com
- Add lib subpackage
* Mon Apr 20 2015 g.bluehut@gmail.com
- Run spec-cleaner
* Tue Feb  3 2015 dmacvicar@suse.de
- initial package for 0.8.7
